@@ -1,6 +1,6 @@
 # NOTE: This script assumes that the SEER data is in /data/SEER.  Please change
 # this line to match your data location if it differs
-.seerHome="/data/SEER" 
+.seerHome="~/data/SEER" 
 rm(list=ls()) # note: dot variables defined above persist through such cleanings
 # install.packages("RSQLite")
 # install.packages("bbmle")
@@ -12,7 +12,8 @@ library(plyr)
 library(bbmle)
 library(ggplot2)
 graphics.off()
-windows(height=7,width=8,xpos=-100,ypos=-100) #need to control the device size to
+quartz(height=7,width=8) 
+# windows(height=7,width=8,xpos=-100,ypos=-100) #need to control the device size to
                                     # make things work across computers/screen sizes
 # Note: Figure 1 was drawn using Adobe Illustrator so it is not reproduced here.
 ######################   
@@ -25,7 +26,7 @@ dbListFields(con,"lymyleuk")
 pop=dbGetQuery(con,"SELECT * from pops where popage>5 and popage<19")
 head(pop)
 (pop<-ddply(pop, .(popage,popsex,popyear), summarise,py=sum(population)))
-pop$dec= cut(pop$popyear,breaks=c(1972,1984,1996,2010),labels=c("73to84","85to96","97to10"))
+pop$dec= cut(pop$popyear,breaks=c(1972,1984,1996,2013),labels=c("73to84","85to96","97to11"))
 (pop<-ddply(pop, .(popage,popsex,dec), summarise,py=sum(py)))
 head(pop,20)
 
@@ -33,7 +34,7 @@ d=dbGetQuery(con,
     "SELECT * from lymyleuk where histo2=9863 and seqnum<2 and agerec>5 and agerec<19")
 head(d)
 (d<-ddply(d, .(agerec,sex,yrdx), summarise,cases=length(agerec))) 
-d$decade= cut(d$yrdx,breaks=c(1972,1984,1996,2011),labels=c("73to84","85to96","97to10"))
+d$decade= cut(d$yrdx,breaks=c(1972,1984,1996,2013),labels=c("73to84","85to96","97to11"))
 head(d)
 (d<-ddply(d, .(agerec,sex,decade), summarise,cases=sum(cases)))
 head(cbind(d,pop)) # just to see that they match up
@@ -43,7 +44,7 @@ head(d)
 d9=dbGetQuery(con, 
         "SELECT * from lymyleuk where ICD9=2051 and seqnum<2 and agerec>5 and agerec<19")
 d9<-ddply(d9, .(sex,agerec,yrdx), summarise,cases=length(agerec))
-d9$decade= cut(d9$yrdx,breaks=c(1972,1984,1996,2010),labels=c("73to84","85to96","97to10"))
+d9$decade= cut(d9$yrdx,breaks=c(1972,1984,1996,2013),labels=c("73to84","85to96","97to11"))
 d9<-ddply(d9, .(agerec,sex,decade), summarise,cases=sum(cases))
 d9=cbind(d9,py=pop[,"py"])
 head(d9)
@@ -55,7 +56,7 @@ age=c(0.5,3,seq(7.5,87.5,5))
 d$age=age[d$agerec+1]
 head(d,15)
 names(d)[3]="Decade" # make legend start with capital
-(p <- ggplot(d,aes(x=age,y=incid,shape=Decade))+geom_point(size=5)
+(p <- ggplot(d,aes(x=age,y=incid,shape=Decade,col=Decade))+geom_point(size=5)
  + labs(title="CML Incidence",x="Age (years)",
         y=expression(paste("Cases per ",10^6," Person-Years")))    
  + scale_y_log10(limits=c(3,200)) )
@@ -101,7 +102,7 @@ mkCIk=function(v) sprintf("k = %4.3f (%4.3f, %4.3f)",v[1],v[2],v[3])
 
 library(ggplot2)
 (p <- ggplot(d,aes(x=age,y=incid,shape=Sex))+geom_point(size=5)
- + labs(title="CMML Incidence: SEER 2000-2010",x="Age (years)",
+ + labs(title="CMML Incidence: SEER 2000-2011",x="Age (years)",
         y=expression(paste("Cases per ",10^6," Person-Years")))  #  y=expression(frac(Cases,paste(10^6," Person-Years")))) 
  + scale_y_log10(limits=c(0.1,70)) )
 
@@ -297,7 +298,8 @@ mkCases=function(n) sprintf("%d cases",n)
 
 
 graphics.off()
-windows(height=6,width=12,xpos=-100,ypos=-100) #need to control the device size to
+# windows(height=6,width=12,xpos=-100,ypos=-100) #need to control the device size to
+quartz(height=6,width=12) 
 library(ggplot2)
 require(grid) # to avoid "cannot find unit()"
 (p <- ggplot(d,aes(x=age,y=incid,shape=Sex)) + geom_point(size=5) 
@@ -334,8 +336,8 @@ dbListFields(con,"lymyleuk")
 pop=dbGetQuery(con,"SELECT * from pops where popage>5 and popage<19 and poprace=1")
 head(pop)
 (pop<-ddply(pop, .(popage,popsex,popyear), summarise,py=sum(population)))
-yearS=c("73to77","78to82","83to87","88to92","93to99","00to04","05to10")
-pop$Years=cut(pop$popyear,breaks=c(1972,1977,1982,1987,1992,1999,2004,2011),labels=yearS)
+yearS=c("73to77","78to82","83to87","88to92","93to99","00to04","05to11")
+pop$Years=cut(pop$popyear,breaks=c(1972,1977,1982,1987,1992,1999,2004,2012),labels=yearS)
 (pop<-ddply(pop,.(popage,popsex,Years),summarise,py=sum(py)))
 head(pop,20)
 
@@ -344,7 +346,7 @@ d=dbGetQuery(con,
 # "SELECT * from lymyleuk where race=1 and ICD9=2051 and seqnum<2 and agerec>5 and agerec<19")
 head(d)
 d<-ddply(d, .(agerec,sex,yrdx), summarise,cases=length(agerec))
-d$Years=cut(d$yrdx,breaks=c(1972,1977,1982,1987,1992,1999,2004,2011),labels=yearS)
+d$Years=cut(d$yrdx,breaks=c(1972,1977,1982,1987,1992,1999,2004,2013),labels=yearS)
 head(d)
 d<-ddply(d, .(agerec,sex,Years), summarise,cases=sum(cases))
 head(cbind(d,pop)) # just to see that they match up
@@ -383,8 +385,8 @@ pop=dbGetQuery(con,
 "SELECT * from pops where poprace=1 and popyear>1999 and popage>5 and popage<19")
 pop<-ddply(pop, .(popage,popsex,popyear), summarise,py=sum(population))
 head(pop,20)
-yearS=c("00to01","02to03","04to05","06to07","08to10")
-pop$Years=cut(pop$popyear,breaks=c(1999,2001,2003,2005,2007,2011),labels=yearS)
+yearS=c("00to01","02to03","04to05","06to07","08to11")
+pop$Years=cut(pop$popyear,breaks=c(1999,2001,2003,2005,2007,2013),labels=yearS)
 pop<-ddply(pop,.(popage,popsex,Years),summarise,py=sum(py))
 head(pop,20)
 
@@ -392,7 +394,7 @@ d=dbGetQuery(con,
 "SELECT * from lymyleuk where race=1 and histo2=9863 and seqnum<2 and agerec>5 and agerec<19")
 # "SELECT * from lymyleuk where race=1 and ICD9=2051 and seqnum<2 and agerec>5 and agerec<19")
 d<-ddply(d, .(agerec,sex,yrdx), summarise,cases=length(agerec))
-d$Years=cut(d$yrdx,breaks=c(1999,2001,2003,2005,2007,2011),labels=yearS)
+d$Years=cut(d$yrdx,breaks=c(1999,2001,2003,2005,2007,2013),labels=yearS)
 d<-ddply(d, .(agerec,sex,Years), summarise,cases=sum(cases))
 head(cbind(d,pop)) # just to see that they match up
 d=cbind(d,py=pop[,"py"])
@@ -422,12 +424,13 @@ for (Y in yearS) {
 dfk18=data.frame(years,k,kL,kU,Registries="SEER18")
 dfk=rbind(dfk9,dfk18)
 
-windows(height=7,width=8,xpos=-100,ypos=-100)  # set back to square
+quartz(height=7,width=8)  # set back to square
+# windows(height=7,width=8,xpos=-100,ypos=-100)  # set back to square
 library(ggplot2)
 pd <- position_dodge(1) 
 (p=ggplot(dfk, aes(x=years, y=k,shape=Registries)) + 
    geom_point(size=6,position=pd))
-(p=p+labs(title="SEER9 1973-2010 and SEER18 2000-2010",x="Year", y="k") )     
+(p=p+labs(title="SEER9 1973-2011 and SEER18 2000-2011",x="Year", y="k") )     
 (p=p+geom_errorbar(aes(ymin=kL, ymax=kU),width=.01,position=pd))
 (p=p+theme(plot.title = element_text(size = rel(2)),
            axis.title = element_text(size = rel(2)),
@@ -459,7 +462,7 @@ head(d,15)
 
 library(ggplot2)
 (p <- ggplot(d,aes(x=age,y=incid,shape=Sex))+geom_point(size=5)
- + labs(title="AML Incidence: SEER 2000-2010",x="Age (years)",
+ + labs(title="AML Incidence: SEER 2000-2011",x="Age (years)",
         y=expression(paste("Cases per ",10^5," Person-Years")))  #  y=expression(frac(Cases,paste(10^6," Person-Years")))) 
  + scale_y_log10(limits=c(0.7,30)) )
 
@@ -526,7 +529,7 @@ mkCIA=function(v) {v=exp(-v); sprintf("M/F = %4.2f (%4.2f, %4.2f)",v[1],v[3],v[2
 mkCIT=function(v) sprintf("Tf = %3.1f (%3.1f, %3.1f)",v[1],v[2],v[3])
 
 (p <- ggplot(d,aes(x=age,y=incid,shape=sex))+geom_point(size=5)
- + labs(title="CML Incidence: SEER 2000-2010",x="Age (years)",
+ + labs(title="CML Incidence: SEER 2000-2011",x="Age (years)",
         y=expression(frac(Cases,paste(10^6," Person-Years")))) 
  + scale_y_log10(limits=c(3,100)) )
 (p=p+theme(title = element_text(size = rel(2)),axis.text = element_text(size = rel(2)))  )
@@ -545,15 +548,15 @@ pop=dbGetQuery(con,
      "SELECT * from pops where poprace=1 and popyear>1999 and popage>9 and popage<19")
 pop<-ddply(pop, .(popage,popsex,popyear), summarise,py=sum(population),.drop=F)
 head(pop,20)
-yearS=c("01to03","04to05","06to07","08to10")
-pop$Years=cut(pop$popyear,breaks=c(1999,2003,2005,2007,2011),labels=yearS)
+yearS=c("01to03","04to05","06to07","08to11")
+pop$Years=cut(pop$popyear,breaks=c(1999,2003,2005,2007,2013),labels=yearS)
 pop<-ddply(pop,.(popage,popsex,Years),summarise,py=sum(py),.drop=F)
 head(pop,20)
 dim(pop)
 
 d=dbGetQuery(con, 
-# "SELECT * from lymyleuk where race=1 and ICD9=2051 and
-#              seqnum<2 and agerec>9 and agerec<19")
+"SELECT * from lymyleuk where race=1 and ICD9=2051 and
+             seqnum<2 and agerec>9 and agerec<19")
 # "SELECT * from lymyleuk where race=1 and histo2=9863 and
 #               seqnum<2 and agerec>9 and agerec<19")
 # "SELECT * from lymyleuk where race=1 and 
@@ -566,10 +569,11 @@ d=dbGetQuery(con,
 # seqnum<2 and agerec>9 and agerec<19")
 # "SELECT * from lymyleuk where race=1 and histo3=9945 and
 # seqnum<2 and agerec>9 and agerec<19")
+head(d)
 d<-ddply(d, .(agerec,sex,yrdx), summarise,cases=length(agerec),.drop=F)
 sum(d$cases)  #2970 icdo2 9863 cases is same as icdO3 9863+9875+9876
 # of the latter, 2425 are 9863, 507 are 9875 and only 38 are 9876  
-d$Years=cut(d$yrdx,breaks=c(1999,2003,2005,2007,2011),labels=yearS)
+d$Years=cut(d$yrdx,breaks=c(1999,2003,2005,2007,2013),labels=yearS)
 d<-ddply(d, .(agerec,sex,Years), summarise,cases=sum(cases),.drop=F)
 head(cbind(d,pop)) # just to see that they match up
 d=cbind(d,py=pop[,"py"])
@@ -618,3 +622,4 @@ data.frame(years,k,kL,kU)
 
 # so bcr-abl negative CML's do have a larger k/aging rate constant, 
 # but since we used icdo2 9863, this cannot explain the ongoing drops in k
+
